/**************************************************************************/
/*  parchit.h Version 3.0                                                 */
/*  Copyright (C) 1992, 1999 Mariano Alvarez Fernandez                    */
/**************************************************************************/
/*  Definiciones, estructuras y prototipos de parchit.c                   */
/**************************************************************************/

#define AMAR     0
#define AZUL     1
#define ROJO     2
#define VERD     3
#define VACIO   -1

#define CASA     0
#define CORREDOR 1
#define LLEGADA  2
#define META     3

#define NORMAL   0
#define SEGURO   1
#define SALIDA   2
#define ENTRADA  3
#define ENTRADA_AMAR  3
#define ENTRADA_AZUL  4
#define ENTRADA_ROJO  5
#define ENTRADA_VERD  6

#define PERSONA  0
#define MAQUINA  1
#define NOJUEGA  2

struct Casillac{
  int f[2];
  int nf[2];
  int tipo;
  };

struct Casillal{
  int f[2];
  int nf[2];
  };

struct Casilla4{
  int f[4];
  int nf[4];
  };

struct Posicion{
  int lugar;
  int pos;
  int ind;
  };

struct Jugador{
  int tipo;
  int ha_salido;
  struct Posicion ficha[4];
  };

struct Resumen{
  int nfcasa;
  int nftbl;
  int nfmeta;
  };

struct Tablero{
  int turno;
  int num_jugadores;
  int siguiente_final;
  int orden_final[4];
  struct Jugador jugador[4];
  struct Resumen resumen[4];
  struct Casilla4 casa[4];
  struct Casillac corredor[68];
  struct Casillal llegada[4][8];
  struct Casilla4 meta[4];
  };
  
struct Analisis{
  char entra;   /* entra en el corredor */
  char sale;    /* sale del corredor */
  char meta;    /* entra en la meta */
  char come;    /* come ficha */
  char hpte;    /* hace puente */
  char rpte;    /* rompe puente */
  char dseg;    /* deja seguro */
  char aseg;    /* va a seguro */
  char nficom;  /* n. de fichas comibles en la posicion inicial */
  char nfipel;  /* n. de fichas peligrosas en la posicion inicial */
  char nffcom;  /* n. de fichas comibles en la posicion final */
  char nffpel;  /* n. de fichas peligrosas en la posicion final */
  char ncfin;   /* n. de casillas que faltan para llegar */
  };

struct AnalGlobal{
  int nficom[4][4];
  int nfipel[4][4];
  };

struct Jugada{
  int cjugador;
  int nficha;
  int vdado;
  int cjugdcom;
  int nfichcom;
  struct Analisis anal;
  struct Posicion origen;
  struct Posicion destino;
  };

struct JugadasPosibles{
  int njugadas;
  struct Jugada jugada[4];
  };

void inicia_tablero( struct Tablero *tbl );
void inicia_jugadores( struct Tablero *tbl, int jamar, int jazul,
                       int jrojo, int jverd );
int dado( void );
int hace6a7( struct Tablero *tbl, int cjugador );
int dadocorr( struct Tablero *tbl, int cjugador );
int tipo_jugador( struct Tablero *tbl, int cjugador );
int genera_jugada( struct Tablero *tbl, int cjugador, int nficha,
                   int vdado, struct Jugada *jugada );
int genera_jugadas_posibles( struct Tablero *tbl,
                   struct JugadasPosibles *jpo, int vdado, int cjugador );
int jugada_valida( struct JugadasPosibles *jpo, struct Jugada *jugada );
int realiza_jugada( struct Tablero *tbl, struct Jugada *jugada );
int compara_jugada( struct Jugada *j1, struct Jugada *j2 );
int compara_posicion( struct Posicion *p1, struct Posicion *p2 );
void vacia_casilla_casa( struct Tablero *tbl, int cjugador, int ncasilla );
void vacia_casilla_corredor( struct Tablero *tbl, int pos, int ncasilla );
void vacia_casilla_llegada( struct Tablero *tbl, int cjugador,
                            int pos, int ncasilla );
int a_casa( struct Tablero *tbl, int pos, int ncasilla );
void inicia_analisis( struct Analisis *anal );
void tres_seises( struct Tablero *tbl, int cj, int nf, struct Jugada *jugada );
int paso_adelante( int cjugador, struct Posicion *posini,
                   struct Posicion *posfin );
int paso_atras( int cjugador, struct Posicion *posini,
                struct Posicion *posfin );
void analisis_global( struct Tablero *tbl, struct AnalGlobal *anal );
void completa_info_anl( struct Tablero *tbl, struct JugadasPosibles *jpo );
void elige_jugadam( struct Tablero *tbl, struct JugadasPosibles *jpo,
		    struct Jugada *jugada, int *valores );
int analiza_jugada( struct Jugada *jg );
